var namespacezypp_1_1media =
[
    [ "AttachedMedia", "structzypp_1_1media_1_1AttachedMedia.html", "structzypp_1_1media_1_1AttachedMedia" ],
    [ "AttachPoint", "classzypp_1_1media_1_1AttachPoint.html", "classzypp_1_1media_1_1AttachPoint" ],
    [ "AuthData", "classzypp_1_1media_1_1AuthData.html", "classzypp_1_1media_1_1AuthData" ],
    [ "AuthDataComparator", "structzypp_1_1media_1_1AuthDataComparator.html", "structzypp_1_1media_1_1AuthDataComparator" ],
    [ "AuthenticationReport", "structzypp_1_1media_1_1AuthenticationReport.html", "structzypp_1_1media_1_1AuthenticationReport" ],
    [ "CDTools", "classzypp_1_1media_1_1CDTools.html", "classzypp_1_1media_1_1CDTools" ],
    [ "CommitPreloadReport", "structzypp_1_1media_1_1CommitPreloadReport.html", "structzypp_1_1media_1_1CommitPreloadReport" ],
    [ "CredentialFileReader", "classzypp_1_1media_1_1CredentialFileReader.html", "classzypp_1_1media_1_1CredentialFileReader" ],
    [ "CredentialManager", "classzypp_1_1media_1_1CredentialManager.html", "classzypp_1_1media_1_1CredentialManager" ],
    [ "CredManagerOptions", "structzypp_1_1media_1_1CredManagerOptions.html", "structzypp_1_1media_1_1CredManagerOptions" ],
    [ "CurlAuthData", "classzypp_1_1media_1_1CurlAuthData.html", "classzypp_1_1media_1_1CurlAuthData" ],
    [ "CurlConfig", "structzypp_1_1media_1_1CurlConfig.html", "structzypp_1_1media_1_1CurlConfig" ],
    [ "DownloadProgressReport", "structzypp_1_1media_1_1DownloadProgressReport.html", "structzypp_1_1media_1_1DownloadProgressReport" ],
    [ "MediaBadAttachPointException", "classzypp_1_1media_1_1MediaBadAttachPointException.html", "classzypp_1_1media_1_1MediaBadAttachPointException" ],
    [ "MediaBadCAException", "classzypp_1_1media_1_1MediaBadCAException.html", "classzypp_1_1media_1_1MediaBadCAException" ],
    [ "MediaBadFilenameException", "classzypp_1_1media_1_1MediaBadFilenameException.html", "classzypp_1_1media_1_1MediaBadFilenameException" ],
    [ "MediaBadUrlEmptyDestinationException", "classzypp_1_1media_1_1MediaBadUrlEmptyDestinationException.html", "classzypp_1_1media_1_1MediaBadUrlEmptyDestinationException" ],
    [ "MediaBadUrlEmptyFilesystemException", "classzypp_1_1media_1_1MediaBadUrlEmptyFilesystemException.html", "classzypp_1_1media_1_1MediaBadUrlEmptyFilesystemException" ],
    [ "MediaBadUrlEmptyHostException", "classzypp_1_1media_1_1MediaBadUrlEmptyHostException.html", "classzypp_1_1media_1_1MediaBadUrlEmptyHostException" ],
    [ "MediaBadUrlException", "classzypp_1_1media_1_1MediaBadUrlException.html", "classzypp_1_1media_1_1MediaBadUrlException" ],
    [ "MediaBlock", "structzypp_1_1media_1_1MediaBlock.html", "structzypp_1_1media_1_1MediaBlock" ],
    [ "MediaBlockList", "classzypp_1_1media_1_1MediaBlockList.html", "classzypp_1_1media_1_1MediaBlockList" ],
    [ "MediaCD", "classzypp_1_1media_1_1MediaCD.html", "classzypp_1_1media_1_1MediaCD" ],
    [ "MediaChangeReport", "structzypp_1_1media_1_1MediaChangeReport.html", "structzypp_1_1media_1_1MediaChangeReport" ],
    [ "MediaCIFS", "classzypp_1_1media_1_1MediaCIFS.html", "classzypp_1_1media_1_1MediaCIFS" ],
    [ "MediaCurl", "classzypp_1_1media_1_1MediaCurl.html", "classzypp_1_1media_1_1MediaCurl" ],
    [ "MediaCurl2", "classzypp_1_1media_1_1MediaCurl2.html", "classzypp_1_1media_1_1MediaCurl2" ],
    [ "MediaCurlException", "classzypp_1_1media_1_1MediaCurlException.html", "classzypp_1_1media_1_1MediaCurlException" ],
    [ "MediaCurlInitException", "classzypp_1_1media_1_1MediaCurlInitException.html", "classzypp_1_1media_1_1MediaCurlInitException" ],
    [ "MediaCurlSetOptException", "classzypp_1_1media_1_1MediaCurlSetOptException.html", "classzypp_1_1media_1_1MediaCurlSetOptException" ],
    [ "MediaDIR", "classzypp_1_1media_1_1MediaDIR.html", "classzypp_1_1media_1_1MediaDIR" ],
    [ "MediaDISK", "classzypp_1_1media_1_1MediaDISK.html", "classzypp_1_1media_1_1MediaDISK" ],
    [ "MediaException", "classzypp_1_1media_1_1MediaException.html", "classzypp_1_1media_1_1MediaException" ],
    [ "MediaFileNotFoundException", "classzypp_1_1media_1_1MediaFileNotFoundException.html", "classzypp_1_1media_1_1MediaFileNotFoundException" ],
    [ "MediaFileSizeExceededException", "classzypp_1_1media_1_1MediaFileSizeExceededException.html", "classzypp_1_1media_1_1MediaFileSizeExceededException" ],
    [ "MediaForbiddenException", "classzypp_1_1media_1_1MediaForbiddenException.html", "classzypp_1_1media_1_1MediaForbiddenException" ],
    [ "MediaHandler", "classzypp_1_1media_1_1MediaHandler.html", "classzypp_1_1media_1_1MediaHandler" ],
    [ "MediaHandlerFactory", "classzypp_1_1media_1_1MediaHandlerFactory.html", "classzypp_1_1media_1_1MediaHandlerFactory" ],
    [ "MediaInvalidCredentialsException", "classzypp_1_1media_1_1MediaInvalidCredentialsException.html", "classzypp_1_1media_1_1MediaInvalidCredentialsException" ],
    [ "MediaISO", "classzypp_1_1media_1_1MediaISO.html", "classzypp_1_1media_1_1MediaISO" ],
    [ "MediaIsSharedException", "classzypp_1_1media_1_1MediaIsSharedException.html", "classzypp_1_1media_1_1MediaIsSharedException" ],
    [ "MediaJammedException", "classzypp_1_1media_1_1MediaJammedException.html", "classzypp_1_1media_1_1MediaJammedException" ],
    [ "MediaManager", "classzypp_1_1media_1_1MediaManager.html", "classzypp_1_1media_1_1MediaManager" ],
    [ "MediaManager_Impl", "classzypp_1_1media_1_1MediaManager__Impl.html", "classzypp_1_1media_1_1MediaManager__Impl" ],
    [ "MediaMountException", "classzypp_1_1media_1_1MediaMountException.html", "classzypp_1_1media_1_1MediaMountException" ],
    [ "MediaNetworkCommonHandler", "classzypp_1_1media_1_1MediaNetworkCommonHandler.html", "classzypp_1_1media_1_1MediaNetworkCommonHandler" ],
    [ "MediaNFS", "classzypp_1_1media_1_1MediaNFS.html", "classzypp_1_1media_1_1MediaNFS" ],
    [ "MediaNotADirException", "classzypp_1_1media_1_1MediaNotADirException.html", "classzypp_1_1media_1_1MediaNotADirException" ],
    [ "MediaNotAFileException", "classzypp_1_1media_1_1MediaNotAFileException.html", "classzypp_1_1media_1_1MediaNotAFileException" ],
    [ "MediaNotAttachedException", "classzypp_1_1media_1_1MediaNotAttachedException.html", "classzypp_1_1media_1_1MediaNotAttachedException" ],
    [ "MediaNotDesiredException", "classzypp_1_1media_1_1MediaNotDesiredException.html", "classzypp_1_1media_1_1MediaNotDesiredException" ],
    [ "MediaNotEjectedException", "classzypp_1_1media_1_1MediaNotEjectedException.html", "classzypp_1_1media_1_1MediaNotEjectedException" ],
    [ "MediaNotOpenException", "classzypp_1_1media_1_1MediaNotOpenException.html", "classzypp_1_1media_1_1MediaNotOpenException" ],
    [ "MediaNotSupportedException", "classzypp_1_1media_1_1MediaNotSupportedException.html", "classzypp_1_1media_1_1MediaNotSupportedException" ],
    [ "MediaPlugin", "classzypp_1_1media_1_1MediaPlugin.html", "classzypp_1_1media_1_1MediaPlugin" ],
    [ "MediaPriority", "classzypp_1_1media_1_1MediaPriority.html", "classzypp_1_1media_1_1MediaPriority" ],
    [ "MediaRequestCancelledException", "classzypp_1_1media_1_1MediaRequestCancelledException.html", "classzypp_1_1media_1_1MediaRequestCancelledException" ],
    [ "MediaSource", "classzypp_1_1media_1_1MediaSource.html", "classzypp_1_1media_1_1MediaSource" ],
    [ "MediaSystemException", "classzypp_1_1media_1_1MediaSystemException.html", "classzypp_1_1media_1_1MediaSystemException" ],
    [ "MediaTemporaryProblemException", "classzypp_1_1media_1_1MediaTemporaryProblemException.html", "classzypp_1_1media_1_1MediaTemporaryProblemException" ],
    [ "MediaTimeoutException", "classzypp_1_1media_1_1MediaTimeoutException.html", "classzypp_1_1media_1_1MediaTimeoutException" ],
    [ "MediaUnauthorizedException", "classzypp_1_1media_1_1MediaUnauthorizedException.html", "classzypp_1_1media_1_1MediaUnauthorizedException" ],
    [ "MediaUnmountException", "classzypp_1_1media_1_1MediaUnmountException.html", "classzypp_1_1media_1_1MediaUnmountException" ],
    [ "MediaUnsupportedUrlSchemeException", "classzypp_1_1media_1_1MediaUnsupportedUrlSchemeException.html", "classzypp_1_1media_1_1MediaUnsupportedUrlSchemeException" ],
    [ "MediaVerifierBase", "classzypp_1_1media_1_1MediaVerifierBase.html", "classzypp_1_1media_1_1MediaVerifierBase" ],
    [ "MediaWriteException", "classzypp_1_1media_1_1MediaWriteException.html", "classzypp_1_1media_1_1MediaWriteException" ],
    [ "MetalinkMirror", "structzypp_1_1media_1_1MetalinkMirror.html", "structzypp_1_1media_1_1MetalinkMirror" ],
    [ "MetaLinkParser", "classzypp_1_1media_1_1MetaLinkParser.html", "classzypp_1_1media_1_1MetaLinkParser" ],
    [ "ml_parsedata", "structzypp_1_1media_1_1ml__parsedata.html", "structzypp_1_1media_1_1ml__parsedata" ],
    [ "Mount", "classzypp_1_1media_1_1Mount.html", "classzypp_1_1media_1_1Mount" ],
    [ "MountEntry", "structzypp_1_1media_1_1MountEntry.html", "structzypp_1_1media_1_1MountEntry" ],
    [ "NoVerifier", "classzypp_1_1media_1_1NoVerifier.html", "classzypp_1_1media_1_1NoVerifier" ],
    [ "ProxyInfo", "classzypp_1_1media_1_1ProxyInfo.html", "classzypp_1_1media_1_1ProxyInfo" ],
    [ "ProxyInfoLibproxy", "classzypp_1_1media_1_1ProxyInfoLibproxy.html", "classzypp_1_1media_1_1ProxyInfoLibproxy" ],
    [ "ProxyInfoSysconfig", "classzypp_1_1media_1_1ProxyInfoSysconfig.html", "classzypp_1_1media_1_1ProxyInfoSysconfig" ],
    [ "ScopedDisableMediaChangeReport", "structzypp_1_1media_1_1ScopedDisableMediaChangeReport.html", "structzypp_1_1media_1_1ScopedDisableMediaChangeReport" ],
    [ "TmpUnsetEnv", "structzypp_1_1media_1_1TmpUnsetEnv.html", "structzypp_1_1media_1_1TmpUnsetEnv" ],
    [ "TransferSettings", "classzypp_1_1media_1_1TransferSettings.html", "classzypp_1_1media_1_1TransferSettings" ],
    [ "transition", "structzypp_1_1media_1_1transition.html", "structzypp_1_1media_1_1transition" ],
    [ "UrlResolverPlugin", "classzypp_1_1media_1_1UrlResolverPlugin.html", "classzypp_1_1media_1_1UrlResolverPlugin" ],
    [ "ZsyncParser", "classzypp_1_1media_1_1ZsyncParser.html", "classzypp_1_1media_1_1ZsyncParser" ],
    [ "MediaNr", "namespacezypp_1_1media.html#a13038cc28702080cd6c2016bbb0ab631", null ],
    [ "MediaVerifierRef", "namespacezypp_1_1media.html#a91fafb316575f7b1f00caf90158963cd", null ],
    [ "MediaAccessId", "namespacezypp_1_1media.html#a4b8d0b917dd34b743c9109cf4b60cff6", null ],
    [ "MediaSourceRef", "namespacezypp_1_1media.html#a74c7436dddd8cf1bcaeaa69bde702a8c", null ],
    [ "AttachPointRef", "namespacezypp_1_1media.html#aba5b1b655e4fac999785adfb5bd32c68", null ],
    [ "CurlAuthData_Ptr", "namespacezypp_1_1media.html#a914ddc1a0a58e9913ec7d188d88d23c5", null ],
    [ "CreateFactorySig", "namespacezypp_1_1media.html#acfdd9d8b2920e3f5fd902d8ec2e18773", null ],
    [ "DelFactorySig", "namespacezypp_1_1media.html#a53d8e91988bfcdd2c45653715031aa5f", null ],
    [ "GetProxiesSig", "namespacezypp_1_1media.html#a08a1cdd89a2dc3e81655c90559997bcb", null ],
    [ "FreeProxiesCb", "namespacezypp_1_1media.html#aba07350a215d52b451253b0be1072065", null ],
    [ "AuthData_Ptr", "namespacezypp_1_1media.html#a1c72c0eaacf99a37ebed5a0775da22da", null ],
    [ "MetaDataType", "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825", [
      [ "None", "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825a6adf97f83acf6453d4a6a4b1070f3754", null ],
      [ "Zsync", "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825aa8760d7c86915746134252e4a65751e5", null ],
      [ "MetaLink", "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825aa4f27de733f41d8de8c96ad59ea0c7f4", null ]
    ] ],
    [ "ParserState", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59", [
      [ "STATE_START", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a6423199a3e9580a3ef36d95a3d8610db", null ],
      [ "STATE_METALINK", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a8ac8be2fb09c49a663a08ce6977a0365", null ],
      [ "STATE_FILES", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59afae90bc3907a3ab28a1c3556bca918e4", null ],
      [ "STATE_FILE", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59ac3ab99b4b9491708b02dfaaaf65eeb20", null ],
      [ "STATE_M4FILE", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a140b09043eab1d1ff4aeaf15d7b3933e", null ],
      [ "STATE_SIZE", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a8a553e5c8e1329dd11d172f849c124a9", null ],
      [ "STATE_M4SIZE", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a49396d3fd4df41fb3bd5b3d83e772bf7", null ],
      [ "STATE_VERIFICATION", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59aa8df758af8c88624f2736eaf3a757d7d", null ],
      [ "STATE_HASH", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a1d221559ce780df327603d00e5c19794", null ],
      [ "STATE_M4HASH", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59aef62f20f2eceafbcd7f12a1ace3d5e89", null ],
      [ "STATE_PIECES", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a7f5485a0ef07bb4e6ef27fc9b06e11dd", null ],
      [ "STATE_M4PIECES", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59af361d5d9c0eee9941492a61a14e34207", null ],
      [ "STATE_PHASH", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a7ee9bcd11265cab9ca4cb4d21b6593c7", null ],
      [ "STATE_M4PHASH", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59ac8ad6880d24bf844bb5e1f8ad02f97f7", null ],
      [ "STATE_RESOURCES", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a64b98fd17e3bad00ad58aeb1d3b9a7b7", null ],
      [ "STATE_URL", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59ab1a4612907e48e5d59d331968b638e7a", null ],
      [ "STATE_M4URL", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a6078771c79fa94bed124bb952110371b", null ],
      [ "NUMSTATES", "namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a4f70f18367c79b474e96041a07967157", null ]
    ] ],
    [ "getShare", "namespacezypp_1_1media.html#a15422d1f797c890670d657f1cd655349", null ],
    [ "stripShare", "namespacezypp_1_1media.html#af25012354fbfc66c6b67fd366153ef79", null ],
    [ "ZYPP_DECLARE_OPERATORS_FOR_FLAGS", "namespacezypp_1_1media.html#a253eea8c981a10cb3cf028e3fa9a3f90", null ],
    [ "operator<<", "namespacezypp_1_1media.html#a1650cc07e912327e0b4a3de64e46cae1", null ],
    [ "operator<<", "namespacezypp_1_1media.html#aa04d0f10b87b2000e2861cd47f76048b", null ],
    [ "operator<<", "namespacezypp_1_1media.html#ac629c95cb8382ac07d5b9047d26fa9a4", null ],
    [ "operator<<", "namespacezypp_1_1media.html#ad30f7cc4271c75aaf758527e21680d20", null ],
    [ "operator<<", "namespacezypp_1_1media.html#a2e00dc0213ffd57140749581d1768e24", null ],
    [ "fetchnext", "namespacezypp_1_1media.html#a5e756833b1c7344b64e11041cd1384e7", null ],
    [ "operator<<", "namespacezypp_1_1media.html#a5e0f31d7fbf79da2e20f076c1a1031eb", null ],
    [ "looks_like_meta_data", "namespacezypp_1_1media.html#a2b602bde97e5ca2c3efe468957b130f0", null ],
    [ "looks_like_meta_file", "namespacezypp_1_1media.html#abcad790b9c5cf0bc168571e3180876f3", null ],
    [ "looks_like_meta_file", "namespacezypp_1_1media.html#aa1bcbc8d7dac975bc1c50076fb9dadf8", null ],
    [ "transitions", "namespacezypp_1_1media.html#ae7f05ef6450ab00794a8691f355fbfa1", null ],
    [ "startElement", "namespacezypp_1_1media.html#a851e7eea001f68ef67bed5125de27feb", null ],
    [ "endElement", "namespacezypp_1_1media.html#a79f43ef35d5aadc6c15842c7ead2dcc4", null ],
    [ "characterData", "namespacezypp_1_1media.html#a147c1d7d582224cfe256373e35a16940", null ],
    [ "parseError", "namespacezypp_1_1media.html#acce3f6748a39c6cbd3af492523ad5fd7", null ],
    [ "find_attr", "namespacezypp_1_1media.html#a62325afdd62526c64131928b8aa33c30", null ],
    [ "hexstr2bytes", "namespacezypp_1_1media.html#ab47e20a250cbce7f562ea8ea3aec9cd8", null ],
    [ "hexstr2bytes", "namespacezypp_1_1media.html#a84e552ef2f151b592fb73b9127fd686c", null ],
    [ "getProxyFactory", "namespacezypp_1_1media.html#aec55d6efc21b414524470d20a2f977a5", null ],
    [ "operator<<", "namespacezypp_1_1media.html#ac5ba3149f09d9524e690b4e3f297012f", null ],
    [ "save_creds_in_file", "namespacezypp_1_1media.html#af7529980ff50a73b46e49b6d1633c71d", null ],
    [ "operator<<", "namespacezypp_1_1media.html#ad0fb34a112d9734be755c8bcc4ca938c", null ],
    [ "operator<<", "classzypp_1_1media_1_1MediaSource.html#a00d6f803a3badc2f90017fbba9a7dd65", null ],
    [ "operator<<", "classzypp_1_1media_1_1AttachPoint.html#a4186b4c5950be3265c0cfec47558f819", null ],
    [ "operator<<", "structzypp_1_1media_1_1AttachedMedia.html#ab87d7199d8466bd67441334dd22faffd", null ],
    [ "operator<<", "classzypp_1_1media_1_1UrlResolverPlugin.html#ad903fbdbe4d902b10a97adaa53a5f0d6", null ],
    [ "operator<<", "structzypp_1_1media_1_1MountEntry.html#a3af8e5c14330c17121a5837ab7676f15", null ],
    [ "minMetalinkProbeSize", "namespacezypp_1_1media.html#aaeda865f7e57cc8937a40e4a818e9464", null ]
];